@@ -17,7 +17,7 @@ use Net::Stripe::Customer;
 use Net::Stripe::Subscription;
 use Net::Stripe::Error;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 NAME
 
@@ -25,13 +25,19 @@ Net::Stripe - API client for Stripe.com
 
 =head1 SYNOPSIS
 
- my $stripe = Net::Stripe->new(api_key => $API_KEY);
- my $charge = $stripe->post_charge(
-     amount => 12500,
-     currency => 'usd',
-     card => $card_token,
+ my $stripe     = Net::Stripe->new(api_key = > $API_KEY);
+ my $card_token = 'a token';
+ my $charge = $stripe->post_charge(  # Net::Stripe::Charge
+     amount      => 12500,
+     currency    => 'usd',
+     card        => $card_token,
      description => 'YAPC Registration',
  );
+ print "Charge was not paid!\n" unless $charge->paid;
+ my $card = $charge->card;           # Net::Stripe::Card
+
+ # look up a charge by id
+ my $same_charge = $stripe->get_charge($charge->id);
 
  # ... and the api mirrors https://stripe.com/docs/api
  # Charges: post_charge() get_charge() refund_charge() get_charges()
@@ -148,12 +154,12 @@ Customers: {
     }
 
     method get_customer {
-        my $id = shift || 'get_customer() requires a customer id';
+        my $id = shift || die 'get_customer() requires a customer id';
         return $self->_get("customers/$id");
     }
 
     method delete_customer {
-        my $id = shift || 'delete_customer() requires a customer id';
+        my $id = shift || die 'delete_customer() requires a customer id';
         $id = $id->id if ref($id);
         $self->_delete("customers/$id");
     }
@@ -171,9 +177,9 @@ See https://stripe.com/docs/api for full details.
 
 =head3 post_subscription( PARAMHASH )
 
-=head3 get_subscription( CUSTOMER_ID )
+=head3 get_subscription( customer_id => CUSTOMER_ID )
 
-=head3 delete_subscription( CUSTOMER_ID )
+=head3 delete_subscription( customer_id => CUSTOMER_ID )
 
 =cut
 
@@ -220,7 +226,7 @@ Tokens: {
     }
 
     method get_token {
-        my $id = shift || 'get_token() requires a token id';
+        my $id = shift || die 'get_token() requires a token id';
         return $self->_get("tokens/$id");
     }
 }
@@ -248,12 +254,12 @@ Plans: {
     }
 
     method get_plan {
-        my $id = shift || 'get_plan() requires a plan id';
+        my $id = shift || die 'get_plan() requires a plan id';
         return $self->_get("plans/" . uri_escape($id));
     }
 
     method delete_plan {
-        my $id = shift || 'delete_plan() requires a plan id';
+        my $id = shift || die 'delete_plan() requires a plan id';
         $id = $id->id if ref($id);
         $self->_delete("plans/$id");
     }
@@ -286,12 +292,12 @@ Coupons: {
     }
 
     method get_coupon {
-        my $id = shift || 'get_coupon() requires a coupon id';
+        my $id = shift || die 'get_coupon() requires a coupon id';
         return $self->_get("coupons/" . uri_escape($id));
     }
 
     method delete_coupon {
-        my $id = shift || 'delete_coupon() requires a coupon id';
+        my $id = shift || die 'delete_coupon() requires a coupon id';
         $id = $id->id if ref($id);
         $self->_delete("coupons/$id");
     }
@@ -317,7 +323,7 @@ See https://stripe.com/docs/api for full details.
 
 Invoices: {
     method get_invoice {
-        my $id = shift || 'get_invoice() requires an invoice id';
+        my $id = shift || die 'get_invoice() requires an invoice id';
         return $self->_get("invoices/$id");
     }
 
@@ -326,7 +332,7 @@ Invoices: {
     }
 
     method get_upcominginvoice {
-        my $id = shift || 'get_upcominginvoice() requires a customer id';
+        my $id = shift || die 'get_upcominginvoice() requires a customer id';
         return $self->_get("invoices/upcoming?customer=$id");
     }
 }
@@ -352,7 +358,8 @@ InvoiceItems: {
         # Update from an existing object
         if (@_ == 1) {
             my $i = shift;
-            return $self->_post("invoiceitems/" . $i->id, $i);
+            my $item = $i->clone; $item->clear_currency;
+            return $self->_post("invoiceitems/" . $i->id, $item);
         }
 
         my $invoiceitem = Net::Stripe::Invoiceitem->new(@_);
@@ -360,12 +367,12 @@ InvoiceItems: {
     }
 
     method get_invoiceitem {
-        my $id = shift || 'get_invoiceitem() requires a invoiceitem id';
+        my $id = shift || die 'get_invoiceitem() requires a invoiceitem id';
         return $self->_get("invoiceitems/$id");
     }
 
     method delete_invoiceitem {
-        my $id = shift || 'delete_invoiceitem() requires a invoiceitem id';
+        my $id = shift || die 'delete_invoiceitem() requires a invoiceitem id';
         $id = $id->id if ref($id);
         $self->_delete("invoiceitems/$id");
     }
